@@ -1,10 +1,9 @@
 from scrapeanything.scraper.scraper import Scraper
 
 import undetected_chromedriver.v2 as webdriver
-
-# from selenium import webdriver
-from selenium.webdriver.common.keys import Keys
 from selenium import webdriver
+
+from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
@@ -22,14 +21,14 @@ import base64
 
 class Selenium(Scraper):
 
-    def __init__(self, headless: bool=True, window: dict={}):
+    def __init__(self, headless: bool=True, window: dict={}, user_dir: str=None):
         options = webdriver.ChromeOptions()
 
         #region undetected_chromedriver
         # setting profile
-        options.user_data_dir = "c:\\temp\\profile"
         # another way to set profile is the below (which takes precedence if both variants are used
-        options.add_argument('--user-data-dir=c:\\temp\\profile2')
+        if user_dir is not None:
+            options.add_argument(f'--user-data-dir={user_dir}')
         # just some options passing in to skip annoying popups
         options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
         #endregion undetected_chromedriver
